Base32Codec class
Encodes and decodes 8-bit byte sequences as Base-32 text.
Several alphabets are available as static const instances: standard and
standardNoPadding (RFC 4648), lowercase and lowercaseNoPadding, hex
and hexLower (base32hex), crockford, geohash, z (z-base-32), and
wordSafe.
Properties
- decoder → AlphabetDecoder
-
Returns the decoder of
this, converting fromTtoS.final - encoder → AlphabetEncoder
-
Returns the encoder from
StoT.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
Iterable< int> , Iterable<int> > -
Inverts
this.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Iterable< int> encoded) → Iterable<int> -
Decodes
encodeddata.inherited -
decodeBuffer(
ByteBuffer encoded) → Iterable< int> -
Decodes an
encodedbuffer using this codecinherited -
decodeString(
String encoded) → Iterable< int> -
Decodes an
encodedstring using this codecinherited -
encode(
Iterable< int> input) → Iterable<int> -
Encodes
input.inherited -
encodeBuffer(
ByteBuffer input) → Iterable< int> -
Encodes an
inputbuffer using this codecinherited -
encodeString(
String input) → Iterable< int> -
Encodes an
inputstring using this codecinherited -
fuse<
R> (Codec< Iterable< other) → Codec<int> , R>Iterable< int> , R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- crockford → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of Crockford's Base32:
- geohash → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of Geohash's Base32:
- hex → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of base32hex:
- hexLower → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of lowercase base32hex:
- lowercase → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet:
- lowercaseNoPadding → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet:
- standard → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet described in RFC-4648:
- standardNoPadding → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet described in RFC-4648:
- wordSafe → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the Word-safe alphabet:
- z → const Base32Codec
- Codec instance to encode and decode 8-bit integer sequence to 5-bit Base-32 character sequence using the alphabet of z-base-32: