operator == method
Two ByteCollector instances are equal if their bytes are equal.
Implementation
@override
bool operator ==(Object other) =>
identical(this, other) ||
(other is ByteCollector && isEqual(other.bytes));
Two ByteCollector instances are equal if their bytes are equal.
@override
bool operator ==(Object other) =>
identical(this, other) ||
(other is ByteCollector && isEqual(other.bytes));