BlockHashBase<T extends BlockHashSink> class abstract

Base class used by block hash algorithms

Inheritance
Available extensions

Constructors

BlockHashBase()
Const constructor for subclasses and const algorithm instances.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hmac HMAC<T>

Available on T, provided by the HMAConBlockHashBase extension

Gets a HMAC instance builder for this algorithm.
no setter
name String
The name of this algorithm
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<List<int>> stream) Stream<HashDigest>
Transforms the byte array input stream to generate a new stream which contains a single HashDigest
inherited
byteStream(Stream<int> stream, [int bufferSize = 1024]) Future<HashDigest>
Consumes the entire stream of byte array and generates a HashDigest.
inherited
cast<RS, RT>() StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
convert(List<int> input) HashDigest
Process the byte array input and returns a HashDigest.
inherited
createSink() → T
Create a HashDigestSink for generating message-digests
inherited
hex(List<int> input) String
Process the byte array input and returns a hash in hexadecimal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pbkdf2(List<int> salt, {PBKDF2Security security = PBKDF2Security.good, int? iterations, int? keyLength}) PBKDF2

Available on BlockHashBase<BlockHashSink>, provided by the PBKDF2onBlockHashBase extension

Generate a secret using PBKDF2 hash algorithm.
string(String input, [Encoding? encoding]) HashDigest
Process the input string and returns a HashDigest.
inherited
stringStraem(Stream<String> stream, [Encoding? encoding]) Future<HashDigest>
Consumes the entire stream of string and generates a HashDigest.
inherited
stringStream(Stream<String> stream, [Encoding? encoding]) Future<HashDigest>
Consumes the entire stream of string and generates a HashDigest.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited