MACHash<T extends HashDigestSink> class abstract

Base class for a keyed Message-Authentication-Code (MAC) algorithm.

A MACHash describes the algorithm; call by (or byString) with a key to obtain a MACHashBase instance that can sign and verify messages.

Available extensions

Constructors

MACHash()
Const constructor for subclasses and const instances.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this algorithm
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

by(List<int> key) MACHashBase<T>
Get a MACHashBase instance initialized by a key.
byString(String key, [Encoding? encoding]) MACHashBase<T>
Get a MACHashBase instance initialized by a string key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pbkdf2(List<int> salt, {PBKDF2Security security = PBKDF2Security.good, int? iterations, int? keyLength}) PBKDF2

Available on MACHash<HashDigestSink>, provided by the PBKDF2onMACHashBase extension

Generate a secret using PBKDF2 hash algorithm.
sign(List<int> key, List<int> message) HashDigest
Signing the message using a key to generate a tag.
toString() String
A string representation of this object.
inherited
verify(List<int> key, List<int> tag, List<int> message) bool
Verify if the tag is derived from the message using a key.

Operators

operator ==(Object other) bool
The equality operator.
inherited