Namespace enum

Predefined UUID namespaces defined by RFC-9562, for use as the namespace argument of the name-based UUID versions (uuid.v3, uuid.v5).

Inheritance
Available extensions

Values

dns → const Namespace

The namespace for fully-qualified domain names.

const Namespace._('6ba7b810-9dad-11d1-80b4-00c04fd430c8')
url → const Namespace

The namespace for URLs.

const Namespace._('6ba7b811-9dad-11d1-80b4-00c04fd430c8')
oid → const Namespace

The namespace for ISO Object Identifiers (OIDs).

const Namespace._('6ba7b812-9dad-11d1-80b4-00c04fd430c8')
x500 → const Namespace

The namespace for X.500 Distinguished Names (DNs).

const Namespace._('6ba7b814-9dad-11d1-80b4-00c04fd430c8')
nil → const Namespace

The special Nil UUID, with all bits set to zero.

const Namespace._('00000000-0000-0000-0000-000000000000')
max → const Namespace

The special Max UUID, with all bits set to one.

const Namespace._('ffffffff-ffff-ffff-ffff-ffffffffffff')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The string value of this namespace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

time String
Generates a fresh time-based (version 6) UUID string.
no setter

Constants

values → const List<Namespace>
A constant List of the values in this enum, in order of their declaration.